@@ -166,7 +166,7 @@ class Foreperson:
         if 'visit' in keys:
             self.data_source.origin.id = recipe['visit']['visit id']
             if 'date' in recipe['visit'].keys():
-                self.data_state.origin.date = datetime.datetime.strptime(recipe['visit']['date'], '%Y-%m-%d')
+                self.data_source.origin.date = datetime.datetime.strptime(str(recipe['visit']['date']), '%Y-%m-%d')
                 self.data_source.origin.year = self.data_state.origin.date.year()
             if 'local contact' in recipe['visit'].keys():
                 self.data_source = recipe['visit']['local contact']
